==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Mirror/ts/Mirror_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Mirror</name>
    <message>
        <location filename="../Mirror.js" line="+62"/>
        <source>First point of symmetry axis</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt linii odbicia</translatorcomment>
        <translation type="unfinished">Pierwszy punkt osi symetrii</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point of symmetry axis</source>
        <translatorcomment>--google--
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation type="unfinished">Drugi punkt osi symetrii</translation>
    </message>
    <message>
        <location filename="../MirrorInit.js" line="+2"/>
        <source>&amp;Mirror</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Odbijaj</translatorcomment>
        <translation type="unfinished">&amp;Odbijaj</translation>
    </message>
</context>
<context>
    <name>MirrorOptions</name>
    <message>
        <location filename="../MirrorDialog.ui" line="+14"/>
        <source>Mirror Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje odbić</translatorcomment>
        <translation type="unfinished">Opcje odbić</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Mirror/ts/Mirror_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Mirror</name>
    <message>
        <location filename="../Mirror.js" line="+62"/>
        <source>First point of symmetry axis</source>
        <translatorcomment>--google--
Wskaż pierwszy punkt linii odbicia</translatorcomment>
        <translation>Proszę wskazać pierwszy punkt osi symetrii</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point of symmetry axis</source>
        <translatorcomment>--google--
Wskaż drugi punkt linii odbicia</translatorcomment>
        <translation>Proszę wskazać drugi punkt osi symetrii</translation>
    </message>
    <message>
        <location filename="../MirrorInit.js" line="+2"/>
        <source>&amp;Mirror</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Odbijaj</translatorcomment>
        <translation>Odbij &amp;lustrzanie</translation>
    </message>
</context>
<context>
    <name>MirrorOptions</name>
    <message>
        <location filename="../MirrorDialog.ui" line="+14"/>
        <source>Mirror Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje odbić</translatorcomment>
        <translation>Opcje odbicia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+79"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie bieżącej warstwy i &amp;atrybutów</translation>
    </message>
</context>
</TS>
